'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = packInScope;

var _consumer;

function _load_consumer() {
  return _consumer = require('../../../consumer');
}

var _bitId;

function _load_bitId() {
  return _bitId = require('../../../bit-id');
}

var _scope;

function _load_scope() {
  return _scope = require('../../../scope');
}

var _exceptions;

function _load_exceptions() {
  return _exceptions = require('../../../consumer/exceptions');
}

var _logger;

function _load_logger() {
  return _logger = _interopRequireDefault(require('../../../logger/logger'));
}

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function packInScope(_ref) {
  var id = _ref.id,
      scopePath = _ref.scopePath,
      directory = _ref.directory,
      writeBitDependencies = _ref.writeBitDependencies,
      links = _ref.links,
      override = _ref.override;

  (_logger || _load_logger()).default.debug(`pack in scope, id: ${id}, scopePath: ${scopePath}`);
  function loadFromScope(initialError) {
    return (0, (_scope || _load_scope()).loadScope)(scopePath || process.cwd()).catch(function (newErr) {
      return Promise.reject(initialError || newErr);
    }).then(function (scope) {
      var bitId = (_bitId || _load_bitId()).BitId.parse(id);
      return scope.pack({ bitId, directory, writeBitDependencies, links, override });
    }).catch(function (e) {
      return Promise.reject(e);
    });
  }

  function loadFromConsumer() {
    return (0, (_consumer || _load_consumer()).loadConsumer)().then(function (consumer) {
      var bitId = (_bitId || _load_bitId()).BitId.parse(id);
      return consumer.scope.pack({ bitId, directory, writeBitDependencies, links, override });
    });
  }

  if (scopePath) return loadFromScope();

  return loadFromConsumer().catch(function (err) {
    if (!(err instanceof (_exceptions || _load_exceptions()).ConsumerNotFound)) throw err;
    return loadFromScope(err);
  });
}
//# sourceMappingURL=pack-in-scope.js.map